Flyte Language and API specification
====================================

The protocol buffers defined here provide a high level specification of various
entities in Flyte control plane and data plane. It provides detailed definition
and documentation of all these entities.

.. toctree::
	:maxdepth: 1
	:caption: flyteidl
	:name: flyteidltoc

	docs/admin/index
	docs/core/index
	docs/datacatalog/index
	docs/event/index
	docs/plugins/index
	docs/service/index
